You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by al...@apache.org on 2017/03/21 02:19:50 UTC

[1/2] beam git commit: Clean source files from dataflow/google references

Repository: beam
Updated Branches:
  refs/heads/master 4ffd43ed7 -> f7855842d


Clean source files from dataflow/google references


Project: http://git-wip-us.apache.org/repos/asf/beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/beam/commit/be224134
Tree: http://git-wip-us.apache.org/repos/asf/beam/tree/be224134
Diff: http://git-wip-us.apache.org/repos/asf/beam/diff/be224134

Branch: refs/heads/master
Commit: be2241346669777862e20eb6def8c50d67fb8249
Parents: 4ffd43e
Author: Ahmet Altay <al...@google.com>
Authored: Mon Mar 20 18:14:31 2017 -0700
Committer: Ahmet Altay <al...@google.com>
Committed: Mon Mar 20 19:19:17 2017 -0700

----------------------------------------------------------------------
 sdks/python/apache_beam/__init__.py           |  2 +-
 sdks/python/apache_beam/io/iobase.py          | 11 ++++-------
 sdks/python/apache_beam/transforms/trigger.py |  2 +-
 3 files changed, 6 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/beam/blob/be224134/sdks/python/apache_beam/__init__.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/__init__.py b/sdks/python/apache_beam/__init__.py
index e680c9e..9921498 100644
--- a/sdks/python/apache_beam/__init__.py
+++ b/sdks/python/apache_beam/__init__.py
@@ -17,7 +17,7 @@
 
 """Apache Beam SDK for Python.
 
-Apache Beam <http://cloud.google.com/dataflow/>
+Apache Beam <https://beam.apache.org/>
 provides a simple, powerful programming model for building both batch
 and streaming parallel data processing pipelines.
 

http://git-wip-us.apache.org/repos/asf/beam/blob/be224134/sdks/python/apache_beam/io/iobase.py
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/transforms/trigger.py b/sdks/python/apache_beam/transforms/trigger.py
index b55d602..e35c349 100644
--- a/sdks/python/apache_beam/transforms/trigger.py
+++ b/sdks/python/apache_beam/transforms/trigger.py
@@ -122,7 +122,7 @@ class WatermarkHoldStateTag(StateTag):
 class TriggerFn(object):
   """A TriggerFn determines when window (panes) are emitted.
 
-  See https://cloud.google.com/dataflow/model/triggers.
+  See https://beam.apache.org/documentation/programming-guide/#triggers
   """
   __metaclass__ = ABCMeta
 


[2/2] beam git commit: This closes #2278

Posted by al...@apache.org.
This closes #2278


Project: http://git-wip-us.apache.org/repos/asf/beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/beam/commit/f7855842
Tree: http://git-wip-us.apache.org/repos/asf/beam/tree/f7855842
Diff: http://git-wip-us.apache.org/repos/asf/beam/diff/f7855842

Branch: refs/heads/master
Commit: f7855842d9c132473bef3096bba7cb9f5c281567
Parents: 4ffd43e be22413
Author: Ahmet Altay <al...@google.com>
Authored: Mon Mar 20 19:19:37 2017 -0700
Committer: Ahmet Altay <al...@google.com>
Committed: Mon Mar 20 19:19:37 2017 -0700

----------------------------------------------------------------------
 sdks/python/apache_beam/__init__.py           |  2 +-
 sdks/python/apache_beam/io/iobase.py          | 11 ++++-------
 sdks/python/apache_beam/transforms/trigger.py |  2 +-
 3 files changed, 6 insertions(+), 9 deletions(-)
----------------------------------------------------------------------
diff --git a/sdks/python/apache_beam/io/iobase.py b/sdks/python/apache_beam/io/iobase.py
index bd40a3e..057f853 100644
--- a/sdks/python/apache_beam/io/iobase.py
+++ b/sdks/python/apache_beam/io/iobase.py
@@ -559,9 +559,9 @@ class RangeTracker(object):
 
 
 class Sink(HasDisplayData):
   """A resource that can be written to using the ``df.io.Write`` transform.
 
   Here ``df`` stands for Dataflow Python code imported in following manner.
   ``import apache_beam as beam``.
 
   A parallel write to an ``iobase.Sink`` consists of three phases:
@@ -572,9 +572,6 @@ class Sink(HasDisplayData):
   3. A sequential *finalization* phase (e.g., committing the writes, merging
      output files, etc.)
 
-  For exact definition of a Dataflow bundle please see
-  https://cloud.google.com/dataflow/faq.
-
   Implementing a new sink requires extending two classes.
 
   1. iobase.Sink
@@ -594,7 +591,7 @@ class Sink(HasDisplayData):
   single record from the bundle and ``close()`` which is called once
   at the end of writing a bundle.
 
   See also ``df.io.fileio.FileSink`` which provides a simpler API for writing
   sinks that produce files.
 
   **Execution of the Write transform**
@@ -692,7 +689,7 @@ class Sink(HasDisplayData):
 
   For more information on creating new sinks please refer to the official
   documentation at
-  ``https://cloud.google.com/dataflow/model/custom-io#creating-sinks``.
+  ``https://beam.apache.org/documentation/sdks/python-custom-io#creating-sinks``
   """
 
   def initialize_write(self):

http://git-wip-us.apache.org/repos/asf/beam/blob/be224134/sdks/python/apache_beam/transforms/trigger.py
----------------------------------------------------------------------
@@ -559,9 +559,9 @@ class RangeTracker(object):
 
 class Sink(HasDisplayData):
-  """A resource that can be written to using the ``df.io.Write`` transform.
+  """A resource that can be written to using the ``beam.io.Write`` transform.
 
@@ -559,9 +559,9 @@ class RangeTracker(object):
 
-  Here ``df`` stands for Dataflow Python code imported in following manner.
+  Here ``beam`` stands for Apache Beam Python code imported in following manner.
   ``import apache_beam as beam``.
 
@@ -594,7 +591,7 @@ class Sink(HasDisplayData):
   at the end of writing a bundle.
 
-  See also ``df.io.fileio.FileSink`` which provides a simpler API for writing
+  See also ``beam.io.fileio.FileSink`` which provides a simpler API for writing
   sinks that produce files.
 